@@ -1,9 +1,7 @@
 #! /usr/bin/env python
 
-# Author: David Goodger
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 2994 $
-# Date: $Date: 2005-02-27 00:44:13 +0100 (Sun, 27 Feb 2005) $
+# $Id: test_raw.py 6268 2010-03-18 22:12:22Z milde $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -13,17 +11,23 @@ Tests for misc.py "raw" directive.
 import os.path
 import sys
 from __init__ import DocutilsTestSupport
-
+from docutils._compat import u_prefix, b
 
 def suite():
     s = DocutilsTestSupport.ParserTestSuite()
     s.generateTests(totest)
     return s
 
-mydir = os.path.dirname(suite.func_code.co_filename)
+mydir = 'test_parsers/test_rst/test_directives/'
 raw1 = os.path.join(mydir, 'raw1.txt')
 utf_16_file = os.path.join(mydir, 'utf-16.csv')
 utf_16_file_rel = DocutilsTestSupport.utils.relative_path(None, utf_16_file)
+utf_16_error_str = ("UnicodeDecodeError: 'ascii' codec can't decode byte 0xfe "
+                    "in position 0: ordinal not in range(128)")
+if sys.version_info < (3,0):
+    utf_16_error_str = ("UnicodeError: Unable to decode input data.  "
+                        "Tried the following encodings: 'ascii'.\n"
+                        "            (%s)" % utf_16_error_str)
 
 totest = {}
 
@@ -94,7 +98,7 @@ totest['raw'] = [
    :file: %s
    :encoding: utf-16
 """ % utf_16_file_rel,
-"""\
+b("""\
 <document source="test data">
     <raw format="html" source="%s" xml:space="preserve">
         "Treat", "Quantity", "Description"
@@ -102,7 +106,7 @@ totest['raw'] = [
         "Crunchy Frog", 1.49, "If we took the b\xf6nes out, it wouldn\\u2019t be
         crunchy, now would it?"
         "Gannet Ripple", 1.99, "\xbfOn a \\u03c3\\u03c4\\u03b9\\u03ba?"
-""" % utf_16_file_rel],
+""" % utf_16_file_rel).decode('raw_unicode_escape')],
 ["""\
 Raw input file is UTF-16-encoded, and is not valid ASCII.
 
@@ -117,14 +121,13 @@ Raw input file is UTF-16-encoded, and is not valid ASCII.
     <system_message level="4" line="3" source="test data" type="SEVERE">
         <paragraph>
             Problem with "raw" directive:
-            UnicodeError: Unable to decode input data.  Tried the following encodings: \'ascii\'.
-            (UnicodeDecodeError: 'ascii' codec can't decode byte 0xfe in position 0: ordinal not in range(128))
+            %s
         <literal_block xml:space="preserve">
             .. raw:: html
                :file: %s
                :encoding: ascii
-""" % utf_16_file_rel],
-["""\
+""" % (utf_16_error_str, utf_16_file_rel)],
+[u"""\
 .. raw:: html
    :encoding: utf-8
 
@@ -135,18 +138,43 @@ Raw input file is UTF-16-encoded, and is not valid ASCII.
     <raw format="html" xml:space="preserve">
         Should the parser complain becau\xdfe there is no :file:?  BUG?
 """],
+["""\
+.. raw:: html
+""",
+"""\
+<document source="test data">
+    <system_message level="3" line="1" source="test data" type="ERROR">
+        <paragraph>
+            Content block expected for the "raw" directive; none found.
+        <literal_block xml:space="preserve">
+            .. raw:: html
+"""],
+["""\
+.. raw:: html
+   :file: non-existent.file
+""",
+"""\
+<document source="test data">
+    <system_message level="4" line="1" source="test data" type="SEVERE">
+        <paragraph>
+            Problems with "raw" directive path:
+            [Errno 2] No such file or directory: %s'non-existent.file'.
+        <literal_block xml:space="preserve">
+            .. raw:: html
+               :file: non-existent.file
+""" % u_prefix],
+# note that this output is rewritten below for certain python versions
 ]
 
-# Skip tests whose output contains "UnicodeDecodeError" if we are not
-# using Python 2.3 or higher.
-if sys.version_info < (2, 3):
-    for i in range(len(totest['raw'])):
-        if totest['raw'][i][1].find('UnicodeDecodeError') != -1:
-            del totest['raw'][i]
-            print ("Test totest['raw'][%s] skipped; "
-                   "Python 2.3+ required for expected output." % i)
-            # Assume we have only one of these tests.
-            break
+# Rewrite tests that depend on the output of IOError as it is
+# platform-dependent before python 2.4 for a unicode path.
+if sys.version_info < (2, 4):
+    # remove the unicode repr u except for py2.3 on windows:
+    if not sys.platform.startswith('win') or sys.version_info < (2, 3):
+        for i in range(len(totest['raw'])):
+            if totest['raw'][i][1].find("u'non-existent.file'") != -1:
+                totest['raw'][i][1] = totest['raw'][i][1].replace(
+                        "u'non-existent.file'", "'non-existent.file'")
 
 
 if __name__ == '__main__':
